iCalendar Anonymizer
Author: icalendar-anonymizer contributors
Description: Anonymize iCalendar files - strip personal data while preserving technical properties
Keywords: icalendar, anonymize, privacy, calendar, ics

## Upload File

Drop file here or click to select Max 10 MB
Advanced Options

Configure how each field is anonymized

Summary
Description
Location
Comment
Contact
Resources
Categories
Attendee
Organizer
UID
Generate shareable link (30-day expiry)

## Paste Content

Advanced Options

Configure how each field is anonymized

Summary
Description
Location
Comment
Contact
Resources
Categories
Attendee
Organizer
UID
Generate shareable link (30-day expiry)

## Fetch from URL

Advanced Options

Configure how each field is anonymized

Summary
Description
Location
Comment
Contact
Resources
Categories
Attendee
Organizer
UID
Generate shareable link (30-day expiry)
Live proxy Always fetches latest calendar data
Static snapshot Stores anonymized copy, expires in 30 days